==> base_aux-0.0.17-py3-none-any.whl: base_aux/funcs/__init__.py <==
# =====================================================================================================================
# VERSION = (0, 0, 1)   # use import EXACT_OBJECTS! not *
#   from .main import *                 # INcorrect
#   from .main import EXACT_OBJECTS     # CORRECT


# =====================================================================================================================
from .static import (
    # BASE
    ValueNotExist,
    # TYPES
    TYPE__VALUE_NOT_PASSED,

    TYPE__VALID_VALIDATOR,
    TYPE__VALID_SOURCE,
    TYPE__VALID_SOURCE_BOOL,
    TYPE__VALID_RESULT,
    TYPE__VALID_RESULT_BOOL,
    TYPE__VALID_RESULT_BOOL__EXX,
    TYPE__VALID_ARGS,
    TYPE__VALID_KWARGS,
    TYPE__VALID_EXCEPTION,
)
# ---------------------------------------------------------------------------------------------------------------------

from .value_0_explicit import (
    # BASE
    Explicit,
    Default,
    # AUX
    # TYPES
    TYPE__EXPLICIT,
    TYPE__DEFAULT,
    # EXX
)
from .args import (
    # BASE
    # AUX
    ArgsEmpty,
    # TYPES
    TYPE__ARGS_EMPTY,
    # EXX
)
from .ensure import (
    # BASE
    args__ensure_tuple,
    ensure_class,
    # AUX
    # TYPES
    # EXX
)

# ---------------------------------------------------------------------------------------------------------------------
# from .result_cum import (
#     # BASE
#     ResultCum,
#     # AUX
#     # TYPES
#     TYPE__RESULT_CUM_STEP,
#     TYPE__RESULT_CUM_STEPS,
#     # EXX
# )
# ---------------------------------------------------------------------------------------------------------------------
from .arrays import array_2d_get_compact_str
from .iter_aux import (
    # BASE
    IterAux,
    # AUX
    # TYPES
    TYPE__ITERABLE_PATH_KEY,
    TYPE__ITERABLE_PATH_ORIGINAL,
    TYPE__ITERABLE_PATH_EXPECTED,
    TYPE__ITERABLE,
    # EXX
)
from .strings import (
    # BASE
    Strings,
    # AUX
    # TYPES
    TYPES_ELEMENTARY_SINGLE,
    TYPES_ELEMENTARY_COLLECTION,
    TYPES_ELEMENTARY,
    TYPE_ELEMENTARY,
    # EXX
)

# =====================================================================================================================
# ---------------------------------------------------------------------------------------------------------------------
from .pytest_aux import (
    # BASE
    pytest_func_tester,
    pytest_func_tester__no_kwargs,
    pytest_func_tester__no_args,
    pytest_func_tester__no_args_kwargs,
    # AUX
    # TYPES
    # EXX
)
# ---------------------------------------------------------------------------------------------------------------------


# =====================================================================================================================

==> base_aux-0.0.20-py3-none-any.whl: base_aux/funcs/__init__.py <==
# =====================================================================================================================
# VERSION = (0, 0, 1)   # use import EXACT_OBJECTS! not *
#   from .main import *                 # INcorrect
#   from .main import EXACT_OBJECTS     # CORRECT


# =====================================================================================================================
from .static import (
    # BASE
    ValueNotExist,
    # TYPES
    TYPE__VALUE_NOT_PASSED,

    TYPE__VALID_VALIDATOR,
    TYPE__VALID_SOURCE,
    TYPE__VALID_SOURCE_BOOL,
    TYPE__VALID_RESULT,
    TYPE__VALID_RESULT_BOOL,
    TYPE__VALID_RESULT_BOOL__EXX,
    TYPE__VALID_ARGS,
    TYPE__VALID_KWARGS,
    TYPE__VALID_EXCEPTION, TYPES_ELEMENTARY_SINGLE, TYPES_ELEMENTARY_COLLECTION, TYPES_ELEMENTARY, TYPE__ELEMENTARY,
)
# ---------------------------------------------------------------------------------------------------------------------

from .value_0_explicit import (
    # BASE
    Explicit,
    Default,
    # AUX
    # TYPES
    TYPE__EXPLICIT,
    TYPE__DEFAULT,
    # EXX
)
from .args import (
    # BASE
    # AUX
    ArgsEmpty,
    # TYPES
    TYPE__ARGS_EMPTY,
    # EXX
)
from .ensure import (
    # BASE
    args__ensure_tuple,
    ensure_class,
    # AUX
    # TYPES
    # EXX
)

# ---------------------------------------------------------------------------------------------------------------------
# from .result_cum import (
#     # BASE
#     ResultCum,
#     # AUX
#     # TYPES
#     TYPE__RESULT_CUM_STEP,
#     TYPE__RESULT_CUM_STEPS,
#     # EXX
# )
# ---------------------------------------------------------------------------------------------------------------------
from .arrays import array_2d_get_compact_str
from .iter_aux import (
    # BASE
    IterAux,
    # AUX
    # TYPES
    TYPE__ITERABLE_PATH_KEY,
    TYPE__ITERABLE_PATH_ORIGINAL,
    TYPE__ITERABLE_PATH_EXPECTED,
    TYPE__ITERABLE,
    # EXX
)
from .text import (
    # BASE
    Text,
    # AUX
    # TYPES
    # EXX
)

# =====================================================================================================================
# ---------------------------------------------------------------------------------------------------------------------
from .pytest_aux import (
    # BASE
    pytest_func_tester,
    pytest_func_tester__no_kwargs,
    pytest_func_tester__no_args,
    pytest_func_tester__no_args_kwargs,
    # AUX
    # TYPES
    # EXX
)
# ---------------------------------------------------------------------------------------------------------------------


# =====================================================================================================================
